@@ -26,12 +26,12 @@ static int outfile_remove (hashcat_ctx_t *hashcat_ctx)
   status_ctx_t   *status_ctx   = hashcat_ctx->status_ctx;
   user_options_t *user_options = hashcat_ctx->user_options;
 
-  u32  dgst_size      = hashconfig->dgst_size;
-  bool is_salted      = hashconfig->is_salted;
-  u32  esalt_size     = hashconfig->esalt_size;
-  u32  hook_salt_size = hashconfig->hook_salt_size;
-  u32  hash_mode      = hashconfig->hash_mode;
-  char separator      = hashconfig->separator;
+  size_t dgst_size      = hashconfig->dgst_size;
+  bool   is_salted      = hashconfig->is_salted;
+  size_t esalt_size     = hashconfig->esalt_size;
+  size_t hook_salt_size = hashconfig->hook_salt_size;
+  u32    hash_mode      = hashconfig->hash_mode;
+  char   separator      = hashconfig->separator;
 
   char *root_directory      = outcheck_ctx->root_directory;
   u32   outfile_check_timer = user_options->outfile_check_timer;
@@ -51,7 +51,7 @@ static int outfile_remove (hashcat_ctx_t *hashcat_ctx)
 
   char **out_files = NULL;
 
-  hc_time_t folder_mtime = 0;
+  time_t folder_mtime = 0;
 
   int out_cnt = 0;
 
@@ -73,9 +73,9 @@ static int outfile_remove (hashcat_ctx_t *hashcat_ctx)
 
         if (is_dir == true)
         {
-          hc_stat_t outfile_check_stat;
+          struct stat outfile_check_stat;
 
-          if (hc_stat (root_directory, &outfile_check_stat) == -1)
+          if (stat (root_directory, &outfile_check_stat) == -1)
           {
             event_log_error (hashcat_ctx, "%s: %s", root_directory, strerror (errno));
 
@@ -107,9 +107,9 @@ static int outfile_remove (hashcat_ctx_t *hashcat_ctx)
                 {
                   if (strcmp (out_info[j].file_name, out_info_new[i].file_name) == 0)
                   {
-                    hc_stat_t outfile_stat;
+                    struct stat outfile_stat;
 
-                    if (hc_stat (out_info_new[i].file_name, &outfile_stat) == 0)
+                    if (stat (out_info_new[i].file_name, &outfile_stat) == 0)
                     {
                       if (outfile_stat.st_ctime == out_info[j].ctime)
                       {
@@ -140,9 +140,9 @@ static int outfile_remove (hashcat_ctx_t *hashcat_ctx)
             {
               //hc_thread_mutex_lock (status_ctx->mux_display);
 
-              hc_stat_t outfile_stat;
+              struct stat outfile_stat;
 
-              if (hc_fstat (fileno (fp), &outfile_stat))
+              if (fstat (fileno (fp), &outfile_stat))
               {
                 fclose (fp);
 
@@ -181,7 +181,7 @@ static int outfile_remove (hashcat_ctx_t *hashcat_ctx)
 
                   if ((hash_mode != 2500) && (hash_mode != 2501) && (hash_mode != 6800))
                   {
-                    parser_status = hashconfig->parse_func ((u8 *) line_buf, line_len - 1, &hash_buf, hashconfig);
+                    parser_status = hashconfig->parse_func ((u8 *) line_buf, (u32) line_len - 1, &hash_buf, hashconfig);
                   }
 
                   u32 found = 0;
