@@ -184,8 +184,10 @@ static const char *const USAGE_BIG[] =
   "  10900 | PBKDF2-HMAC-SHA256                               | Generic KDF",
   "  12100 | PBKDF2-HMAC-SHA512                               | Generic KDF",
   "     23 | Skype                                            | Network Protocols",
-  "   2500 | WPA/WPA2                                         | Network Protocols",
-  "   2501 | WPA/WPA2 PMK                                     | Network Protocols",
+  "   2500 | WPA-EAPOL-PBKDF2                                 | Network Protocols",
+  "   2501 | WPA-EAPOL-PMK                                    | Network Protocols",
+  "  16800 | WPA-PMKID-PBKDF2                                 | Network Protocols",
+  "  16801 | WPA-PMKID-PMK                                    | Network Protocols",
   "   4800 | iSCSI CHAP authentication, MD5(CHAP)             | Network Protocols",
   "   5300 | IKE-PSK MD5                                      | Network Protocols",
   "   5400 | IKE-PSK SHA1                                     | Network Protocols",
@@ -285,7 +287,9 @@ static const char *const USAGE_BIG[] =
   "   9900 | Radmin2                                          | Operating Systems",
   "    125 | ArubaOS                                          | Operating Systems",
   "   7700 | SAP CODVN B (BCODE)                              | Enterprise Application Software (EAS)",
+  "   7701 | SAP CODVN B (BCODE) via RFC_READ_TABLE           | Enterprise Application Software (EAS)",
   "   7800 | SAP CODVN F/G (PASSCODE)                         | Enterprise Application Software (EAS)",
+  "   7801 | SAP CODVN F/G (PASSCODE) via RFC_READ_TABLE      | Enterprise Application Software (EAS)",
   "  10300 | SAP CODVN H (PWDSALTEDHASH) iSSHA-1              | Enterprise Application Software (EAS)",
   "   8600 | Lotus Notes/Domino 5                             | Enterprise Application Software (EAS)",
   "   8700 | Lotus Notes/Domino 6                             | Enterprise Application Software (EAS)",
@@ -336,6 +340,7 @@ static const char *const USAGE_BIG[] =
   "      Y | 2 = XTS 1024 bit cascaded Twofish-Serpent        | Full-Disk Encryption (FDE)",
   "      Y | 3 = XTS 1536 bit all                             | Full-Disk Encryption (FDE)",
   "  14600 | LUKS                                             | Full-Disk Encryption (FDE)",
+  "  16700 | FileVault 2                                      | Full-Disk Encryption (FDE)",
   "   9700 | MS Office <= 2003 $0/$1, MD5 + RC4               | Documents",
   "   9710 | MS Office <= 2003 $0/$1, MD5 + RC4, collider #1  | Documents",
   "   9720 | MS Office <= 2003 $0/$1, MD5 + RC4, collider #2  | Documents",
@@ -366,6 +371,7 @@ static const char *const USAGE_BIG[] =
   "  15600 | Ethereum Wallet, PBKDF2-HMAC-SHA256              | Password Managers",
   "  15700 | Ethereum Wallet, SCRYPT                          | Password Managers",
   "  16300 | Ethereum Pre-Sale Wallet, PBKDF2-HMAC-SHA256     | Password Managers",
+  "  16900 | Ansible Vault                                    | Password Managers",
   "  99999 | Plaintext                                        | Plaintext",
   "",
   "- [ Outfile Formats ] -",
