@@ -15,7 +15,7 @@
 #include "shared.h"
 #include "wordlist.h"
 
-u32 convert_from_hex (hashcat_ctx_t *hashcat_ctx, char *line_buf, const u32 line_len)
+size_t convert_from_hex (hashcat_ctx_t *hashcat_ctx, char *line_buf, const size_t line_len)
 {
   const user_options_t *user_options = hashcat_ctx->user_options;
 
@@ -37,11 +37,11 @@ u32 convert_from_hex (hashcat_ctx_t *hashcat_ctx, char *line_buf, const u32 line
 
   if (user_options->wordlist_autohex_disable == false)
   {
-    if (is_hexify ((const u8 *) line_buf, (const int) line_len) == true)
+    if (is_hexify ((const u8 *) line_buf, line_len) == true)
     {
-      const int new_len = exec_unhexify ((const u8 *) line_buf, (const int) line_len, (u8 *) line_buf, (const int) line_len);
+      const size_t new_len = exec_unhexify ((const u8 *) line_buf, line_len, (u8 *) line_buf, line_len);
 
-      return (u32) new_len;
+      return new_len;
     }
   }
 
@@ -213,7 +213,7 @@ void get_next_word (hashcat_ctx_t *hashcat_ctx, FILE *fd, char **out_buf, u32 *o
 
       memset (rule_buf_out, 0, sizeof (rule_buf_out));
 
-      const int rule_len_out = _old_apply_rule (user_options->rule_buf_l, user_options_extra->rule_len_l, ptr, len, rule_buf_out);
+      const int rule_len_out = _old_apply_rule (user_options->rule_buf_l, user_options_extra->rule_len_l, ptr, (u32) len, rule_buf_out);
 
       if (rule_len_out < 0) continue;
     }
@@ -221,7 +221,7 @@ void get_next_word (hashcat_ctx_t *hashcat_ctx, FILE *fd, char **out_buf, u32 *o
     if (len >= PW_MAX) continue;
 
     *out_buf = ptr;
-    *out_len = len;
+    *out_len = (u32) len;
 
     return;
   }
@@ -242,16 +242,26 @@ void pw_add (hc_device_param_t *device_param, const u8 *pw_buf, const int pw_len
 {
   if (device_param->pws_cnt < device_param->kernel_power)
   {
-    pw_t *pw = device_param->pws_buf + device_param->pws_cnt;
+    pw_idx_t *pw_idx = device_param->pws_idx + device_param->pws_cnt;
 
-    u8 *ptr = (u8 *) pw->i;
+    const u32 pw_len4 = (pw_len + 3) & ~3; // round up to multiple of 4
 
-    memcpy (ptr, pw_buf, pw_len);
+    const u32 pw_len4_cnt = pw_len4 / 4;
 
-    //memset zero to entire buffer done in outer loop
-    //memset (ptr + pw_len, 0, sizeof (pw->i) - pw_len);
+    pw_idx->cnt = pw_len4_cnt;
+    pw_idx->len = pw_len;
 
-    pw->pw_len = pw_len;
+    u8 *dst = (u8 *) (device_param->pws_comp + pw_idx->off);
+
+    memcpy (dst, pw_buf, pw_len);
+
+    memset (dst + pw_len, 0, pw_len4 - pw_len);
+
+    // prepare next element
+
+    pw_idx_t *pw_idx_next = pw_idx + 1;
+
+    pw_idx_next->off = pw_idx->off + pw_idx->cnt;
 
     device_param->pws_cnt++;
   }
@@ -279,7 +289,7 @@ int count_words (hashcat_ctx_t *hashcat_ctx, FILE *fd, const char *dictfile, u64
 
   d.cnt = 0;
 
-  if (hc_fstat (fileno (fd), &d.stat))
+  if (fstat (fileno (fd), &d.stat))
   {
     *result = 0;
 
@@ -347,7 +357,7 @@ int count_words (hashcat_ctx_t *hashcat_ctx, FILE *fd, const char *dictfile, u64
 
       cache_hit_t cache_hit;
 
-      cache_hit.dictfile      = (char *) dictfile;
+      cache_hit.dictfile      = dictfile;
       cache_hit.stat.st_size  = d.stat.st_size;
       cache_hit.cached_cnt    = cached_cnt;
       cache_hit.keyspace      = keyspace;
@@ -360,12 +370,12 @@ int count_words (hashcat_ctx_t *hashcat_ctx, FILE *fd, const char *dictfile, u64
     }
   }
 
-  hc_time_t rt_start;
+  time_t rt_start;
 
-  hc_time (&rt_start);
+  time (&rt_start);
 
-  hc_time_t now  = 0;
-  hc_time_t prev = 0;
+  time_t now  = 0;
+  time_t prev = 0;
 
   u64 comp = 0;
   u64 cnt  = 0;
@@ -415,7 +425,7 @@ int count_words (hashcat_ctx_t *hashcat_ctx, FILE *fd, const char *dictfile, u64
 
         memset (rule_buf_out, 0, sizeof (rule_buf_out));
 
-        const int rule_len_out = _old_apply_rule (user_options->rule_buf_l, user_options_extra->rule_len_l, ptr, len, rule_buf_out);
+        const int rule_len_out = _old_apply_rule (user_options->rule_buf_l, user_options_extra->rule_len_l, ptr, (u32) len, rule_buf_out);
 
         if (rule_len_out < 0) continue;
       }
@@ -449,11 +459,11 @@ int count_words (hashcat_ctx_t *hashcat_ctx, FILE *fd, const char *dictfile, u64
       }
     }
 
-    hc_time (&now);
+    time (&now);
 
     if ((now - prev) == 0) continue;
 
-    hc_time (&prev);
+    time (&prev);
 
     double percent = ((double) comp / (double) d.stat.st_size) * 100;
 
@@ -461,7 +471,7 @@ int count_words (hashcat_ctx_t *hashcat_ctx, FILE *fd, const char *dictfile, u64
     {
       cache_generate_t cache_generate;
 
-      cache_generate.dictfile    = (char *) dictfile;
+      cache_generate.dictfile    = dictfile;
       cache_generate.comp        = comp;
       cache_generate.percent     = percent;
       cache_generate.cnt         = cnt;
@@ -471,13 +481,13 @@ int count_words (hashcat_ctx_t *hashcat_ctx, FILE *fd, const char *dictfile, u64
     }
   }
 
-  hc_time_t rt_stop;
+  time_t rt_stop;
 
-  hc_time (&rt_stop);
+  time (&rt_stop);
 
   cache_generate_t cache_generate;
 
-  cache_generate.dictfile    = (char *) dictfile;
+  cache_generate.dictfile    = dictfile;
   cache_generate.comp        = comp;
   cache_generate.percent     = 100;
   cache_generate.cnt         = cnt;
